@@ -15,7 +15,7 @@ from typing import Union
 from typing import Tuple
 from math import isnan
 from copy import deepcopy
-from sklearn.preprocessing import scale
+from sklearn.preprocessing import StandardScaler
 from ailca.core.env import *
 from ailca.core.operation import sublist
 from ailca.core.operation import split_list
@@ -144,16 +144,13 @@ class Dataset(torch.utils.data.Dataset):
 
     def split(self,
               ratio_train: float,
-              ratio_val: float = None,
-              random_seed: int = None) -> Union[Tuple[Dataset, Dataset], Tuple[Dataset, Dataset, Dataset]]:
+              random_seed: int = None) -> Tuple[Dataset, Dataset]:
         """
-        Split the dataset into three sub-datasets.
-        If ``ratio_val`` is ``None``, the original dataset is divided into two sub-datasets.
+        Split the dataset into two sub-datasets.
 
         :param ratio_train: (*float*) A ratio of the number of data in the training dataset.
-        :param ratio_val: (*float, optional*) A ratio of the number of data in the validation dataset (*default* = ``None``).
         :param random_seed: (*int, optional*) A random seed to split the dataset (*default* = ``None``).
-        :return: (*Union[Tuple[Dataset, Dataset], Tuple[Dataset, Dataset, Dataset]]*) Three sub-datasets of the original dataset.
+        :return: (*Tuple[Dataset, Dataset]*) Three sub-datasets of the original dataset.
         """
 
         if random_seed is not None:
@@ -161,19 +158,10 @@ class Dataset(torch.utils.data.Dataset):
 
         idx_rand = numpy.random.permutation(len(self))
         n_data_train = int(ratio_train * len(self))
+        dataset_train = self.clone(x=sublist(self.data, idx_rand[:n_data_train]))
+        dataset_test = self.clone(x=sublist(self.data, idx_rand[n_data_train:]))
 
-        if ratio_val is None:
-            dataset_train = self.clone(x=sublist(self.data, idx_rand[:n_data_train]))
-            dataset_test = self.clone(x=sublist(self.data, idx_rand[n_data_train:]))
-
-            return dataset_train, dataset_test
-        else:
-            n_data_val = int(ratio_val * len(self))
-            dataset_train = self.clone(x=sublist(self.data, idx_rand[:n_data_train]))
-            dataset_val = self.clone(x=sublist(self.data, idx_rand[n_data_train:n_data_train+n_data_val]))
-            dataset_test = self.clone(x=sublist(self.data, idx_rand[n_data_train+n_data_val:]))
-
-            return dataset_train, dataset_val, dataset_test
+        return dataset_train, dataset_test
 
     def save(self,
              path: str):
@@ -204,7 +192,10 @@ class Dataset(torch.utils.data.Dataset):
         if not isinstance(self._x, torch.Tensor):
             raise TypeError('Only datasets containing \'torch.Tensor\' input data can be normalized.')
 
-        self._x = torch.tensor(scale(self._x), dtype=torch.float)
+        scaler = StandardScaler()
+        self._x = torch.tensor(scaler.fit_transform(self._x), dtype=torch.float)
+        self.metadata['data_norm_mean'] = scaler.mean_.tolist()
+        self.metadata['data_norm_std'] = numpy.sqrt(scaler.var_).tolist()
 
     def complete(self) -> Dataset:
         """
