@@ -39,11 +39,12 @@ class Model(ABC):
 
     @abstractmethod
     def __init__(self,
-                 alg: str = None,
+                 alg_id: str = None,
                  alg_src: str = None):
-        self.__alg_id = alg
+        self.__alg_id = alg_id
         self.__alg_name = ALG_NAMES[self.__alg_id]
         self.__alg_src = alg_src
+        self._model_info = dict()
 
     def __str__(self):
         return '<Algorithm: {}, Source library: {}>'.format(self.alg_name, self.alg_src)
@@ -60,6 +61,10 @@ class Model(ABC):
     def alg_src(self):
         return self.__alg_src
 
+    @property
+    def model_info(self):
+        return self._model_info
+
     @abstractmethod
     def predict(self,
                 data: object):
@@ -101,11 +106,17 @@ class SKLearnModel(Model):
     """
 
     def __init__(self,
-                 alg: str = None,
+                 alg_id: str = None,
                  **kwargs):
-        super(SKLearnModel, self).__init__(alg, SRC_SKLEARN)
+        super(SKLearnModel, self).__init__(alg_id, SRC_SKLEARN)
         self.__model = None
         self.__hparams = deepcopy(kwargs)
+        self._model_info = {
+            'alg_id': self.alg_id,
+            'alg_name': self.alg_name,
+            'alg_src': self.alg_src,
+            'hparams': self.hparams
+        }
 
         self.__init_model(**kwargs)
 
@@ -231,9 +242,9 @@ class PyTorchModel(torch.nn.Module, Model):
 
     @abstractmethod
     def __init__(self,
-                 alg: str = None):
+                 alg_id: str = None):
         torch.nn.Module.__init__(self)
-        Model.__init__(self, alg, SRC_PYTORCH)
+        Model.__init__(self, alg_id, SRC_PYTORCH)
 
         # Model parameters.
         self.__params = self.parameters()
@@ -319,6 +330,10 @@ class PyTorchModel(torch.nn.Module, Model):
         self.load_state_dict(torch.load(path_model_file))
 
     def init(self):
+        """
+        Initialize the prediction model.
+        """
+
         if is_gpu_runnable():
             return self.cuda()
         else:
