@@ -8,9 +8,11 @@ from ailca.core.operation import flatten_lists
 from ailca.data.base import Dataset
 from ailca.data.util import get_data_loader
 from ailca.data.multimodal import MultimodalDataset
-from ailca.ml.base import Model
-from ailca.ml.base import SKLearnModel
-from ailca.ml.base import PyTorchModel
+from ailca.ml.base import Model, SKLearnModel, PyTorchModel
+from ailca.ml.fnn import *
+from ailca.ml.cnn import *
+from ailca.ml.gnn import *
+from ailca.ml.multimodal import MultimodalNet
 
 
 class MLResult:
@@ -36,9 +38,7 @@ class MLResult:
 
         # Store metadata of the prediction model.
         exp_info = dict()
-        exp_info['alg_id'] = self.model.alg_id
-        exp_info['alg_name'] = self.model.alg_name
-        exp_info['alg_src'] = self.model.alg_src
+        exp_info['model_info'] = self.model.model_info
 
         # Store metadata of the dataset.
         if isinstance(self.dataset_train, MultimodalDataset):
@@ -220,3 +220,76 @@ def k_fold_cross_validation(k_folds: list,
     eval_results['r2_test'] = r2_score(targets, preds)
 
     return eval_results
+
+
+def load_exp_info(path_exp_file: str) -> dict:
+    with open(path_exp_file, 'r') as f:
+        return json.loads(f.read())
+
+
+def load_model(model_info: Union[str, dict],
+               path_model_file: str) -> Model:
+    if isinstance(model_info, str):
+        with open(model_info, 'r') as f:
+            _model_info = json.loads(f.read())
+    else:
+        _model_info = model_info
+
+    if _model_info['alg_id'] == ALG_MULTIMODAL:
+        nets = [__config_model(info) for info in _model_info['nets']]
+        model = MultimodalNet(nets=nets, dim_out=_model_info['dim_out']).init()
+    else:
+        model = __config_model(_model_info)
+
+    model.load(path_model_file)
+
+    return model
+
+
+def __config_model(model_info: dict) -> Model:
+    if model_info['alg_src'] == SRC_SKLEARN:
+        model = SKLearnModel(model_info['alg_id'], **model_info['hparams'])
+    else:
+        alg_id = model_info['alg_id']
+
+        if alg_id == ALG_FCNN:
+            layers = [FCLayer(c['dim_in'], c['dim_out'], c['batch_norm'], c['act_func'])
+                      for c in model_info['layers']]
+            model = FCNN(layers)
+        elif alg_id == ALG_RESNET18:
+            model = ResNet18(model_info['dim_out'])
+        elif alg_id == ALG_RESNET34:
+            model = ResNet34(model_info['dim_out'])
+        elif alg_id == ALG_RESNET101:
+            model = ResNet101(model_info['dim_out'])
+        elif alg_id == ALG_DENSENET121:
+            model = DenseNet121(model_info['dim_out'])
+        elif alg_id in ALG_GNNS:
+            aggr_layers = [GNNLayer(c['node_aggr_scheme'], c['dim_in_node'], c['dim_out'],
+                                    c['dim_in_edge'], c['layer_norm'], c['act_func'])
+                           for c in model_info['aggr_layers']]
+            pred_layers = [FCLayer(c['dim_in'], c['dim_out'], c['batch_norm'], c['act_func'])
+                           for c in model_info['pred_layers']]
+
+            if alg_id == ALG_GCN:
+                model = GCN(aggr_layers, pred_layers, readout_method=model_info['readout_method'])
+            elif alg_id == ALG_GAT:
+                model = GAT(aggr_layers, pred_layers, readout_method=model_info['readout_method'])
+            elif alg_id == ALG_GIN:
+                model = GIN(aggr_layers, pred_layers, readout_method=model_info['readout_method'])
+            elif alg_id == ALG_ECCNN:
+                model = ECCNN(aggr_layers, pred_layers, readout_method=model_info['readout_method'])
+            elif alg_id == ALG_CGCNN:
+                node_emb_layers = [FCLayer(c['dim_in'], c['dim_out'], c['batch_norm'], c['act_func'])
+                                   for c in model_info['node_emb_layers']]
+                model = CGCNN(node_emb_layers, aggr_layers, pred_layers, readout_method=model_info['readout_method'])
+            elif alg_id == ALG_TFGNN:
+                model = TFGNN(aggr_layers, pred_layers, readout_method=model_info['readout_method']).init()
+            else:
+                raise KeyError('Unknown algorithm identifier: \'{}\''.format(alg_id))
+        else:
+            raise KeyError('Unknown algorithm identifier: \'{}\''.format(alg_id))
+
+        model.init()
+
+    return model
